# data-core-pipelines-beam
A TDD core project to develop Apache Beam Pipelines with Python SDK

## Deploy by environment
### LOCAL ENV

1. Create Venv
```
# Create Venv
python -m venv /path/to/directory

# Activate venv
. /path/to/directory/bin/activate
```
2. Full list installs applied

```
# Install Apache Beam for local
pip install apache-beam

# Install Apache Beam for GCP
pip install wheel
pip install 'apache-beam[gcp]'
pip install --upgrade 'apache-beam[gcp]'
```

3. Install requirements.txt from current venv
```
# Install Requirements
pip install -r requirements.txt
```

4. Setup Local Environment
    WIP: check JOURNAL_STEPS.md for current working DONE steps to setup data-core-pipelines-beam project




